pyhsm.aes_ecb_cmd.YHSM_Cmd_AES_ECB_Encrypt

Package pyhsm :: Module aes_ecb_cmd :: Class YHSM_Cmd_AES_ECB_Encrypt |
[frames] | no frames]

# Class YHSM_Cmd_AES_ECB_Encrypt

    cmd.YHSM_Cmd --+
                   |
    YHSM_Cmd_AES_ECB --+
                       |
                      YHSM_Cmd_AES_ECB_Encrypt

Have the YubiHSM AES ECB encrypt something using the key of a key handle.

Instance Methods
__init__(self, stick, key_handle, plaintext) The base class for all YSM_ commands. |
Inherited from `YHSM_Cmd_AES_ECB`: `__repr__`, `parse_result` Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
Inherited from `YHSM_Cmd_AES_ECB`: `key_handle`, `status` Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### __init__(self, stick, key_handle, plaintext) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)